pub struct AddLocalDir {
pub remote_path: String,
pub files: Vec<AddLocalDirFile>,
}Expand description
A tree of local files copied into the image under remote_path.
Fields
remote_path: StringAbsolute path inside the rootfs where the files land.
files: Vec<AddLocalDirFile>The files in the tree.