pub struct DockerfileFromResolution {
pub reference: String,
pub digest_ref: String,
}Expand description
What one external image reference in a Dockerfile resolved to when an image was built.
Fields
reference: StringThe reference as the Dockerfile’s FROM or COPY --from names it.
digest_ref: StringThe digest-pinned form of the same reference the build used.