#[non_exhaustive]pub struct ImageBuild {
pub image_id: String,
pub status: ImageBuildStatus,
pub error_message: String,
pub resolved_oci_ref: String,
}Expand description
The state of a custom image build.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.image_id: StringThe content-addressed image id.
status: ImageBuildStatusBuild status.
error_message: StringHuman-readable failure detail when the status is failed, else empty.
resolved_oci_ref: StringThe digest-pinned form of the spec’s registry reference when the spec’s source is an OCI image, and empty otherwise. Creating from this reference instead of the submitted tag keeps naming the same registry content even if the tag has moved since.